function mu = tsmu(T)

% MU = TSMU(T)
%
% Returns the graininess of timescale T as a timescale object MU. By convention,
% the size of MU will be the size of T, with MU(k) = 0 where k is the last index in MU.
%

% Ian Gravagne, 12/29/03 Baylor University

if(~isa(T,'timescale'))
    error('Graininess function TSMU requries a timescale object for input.');
end

t = T(:);
s = size(T);

if(isempty(t) | isempty(s))
    mu = T;
    return;
end

D = isdiscrete(T);
d = D(:);


for(i = [1:size(s,2)])
    if(s(1,i) > 0)
        d(s(1,i)) = 1;
    end
end

grain = [diff(t),0].*d;

mu = timescale(grain,size(T));
